@@ -9,6 +9,7 @@ from path import Path
 
 class VirtualEnv:
     root = Path(os.environ.get('SERVICES_ROOT', '.cache/services'))
+    clean_opts = ["--no-setuptools", "--no-pip", "--no-wheel"]
 
     @property
     def dir(self):
@@ -25,6 +26,8 @@ class VirtualEnv:
         cmd = [sys.executable, '-m', 'virtualenv', self.dir]
         with contextlib.suppress(AttributeError):
             cmd += ['--python', self.python]
+        with contextlib.suppress(AttributeError):
+            cmd += self.create_opts
         subprocess.check_call(cmd)
 
     def install(self):
@@ -47,9 +50,15 @@ class _VEnv(VirtualEnv):
     to be Python 3.
     """
 
+    clean_opts = ["--without-pip"]
+
     def ensure_env(self):
         executable = getattr(self, 'python', sys.executable)
         cmd = [executable, '-m', 'venv', self.dir]
+        with contextlib.suppress(AttributeError):
+            cmd += ['--python', self.python]
+        with contextlib.suppress(AttributeError):
+            cmd += self.create_opts
         subprocess.check_call(cmd)
 
 
